summaryrefslogtreecommitdiff
path: root/TAO/orbsvcs/orbsvcs/SSLIOP/IIOP_SSL_Acceptor.h
diff options
context:
space:
mode:
authorOssama Othman <ossama-othman@users.noreply.github.com>2004-07-31 13:06:28 +0000
committerOssama Othman <ossama-othman@users.noreply.github.com>2004-07-31 13:06:28 +0000
commit3c65107f97847fa7c7c1c98f00a40add0f22246b (patch)
treec5ab363067d2a900c58e1827d11a69956632e213 /TAO/orbsvcs/orbsvcs/SSLIOP/IIOP_SSL_Acceptor.h
parent15171a13e0a22000400853edc7ba861bb2ff14e2 (diff)
downloadATCD-3c65107f97847fa7c7c1c98f00a40add0f22246b.tar.gz
ChangeLogTag:Sat Jul 31 00:43:37 2004 Ossama Othman <ossama@dre.vanderbilt.edu>
Diffstat (limited to 'TAO/orbsvcs/orbsvcs/SSLIOP/IIOP_SSL_Acceptor.h')
-rw-r--r--TAO/orbsvcs/orbsvcs/SSLIOP/IIOP_SSL_Acceptor.h103
1 files changed, 52 insertions, 51 deletions
diff --git a/TAO/orbsvcs/orbsvcs/SSLIOP/IIOP_SSL_Acceptor.h b/TAO/orbsvcs/orbsvcs/SSLIOP/IIOP_SSL_Acceptor.h
index d322d022f9e..4d8e9a03e30 100644
--- a/TAO/orbsvcs/orbsvcs/SSLIOP/IIOP_SSL_Acceptor.h
+++ b/TAO/orbsvcs/orbsvcs/SSLIOP/IIOP_SSL_Acceptor.h
@@ -8,7 +8,7 @@
*
* SSL-aware IIOP specific acceptor processing
*
- * @author Ossama Othman <ossama@uci.edu>
+ * @author Ossama Othman <ossama@dre.vanderbilt.edu>
*/
//=============================================================================
@@ -18,76 +18,77 @@
#include /**/ "ace/pre.h"
-#include "SSLIOP_Export.h"
+#include "IIOP_SSL_Connection_Handler.h"
#if !defined (ACE_LACKS_PRAGMA_ONCE)
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */
-#include "IIOP_SSL_Connection_Handler.h"
#include "SSLIOP_Connection_Handler.h"
#include "tao/IIOP_Acceptor.h"
-// TAO IIOP_SSL_Acceptor concrete call defination
-
-/**
- * @class TAO_IIOP_SSL_Acceptor
- *
- * @brief An SSL aware IIOP acceptor.
- *
- * The class differs from the non-SSL aware TAO_IIOP_Acceptor class
- * since it uses a different a set of Acceptor strategies. In
- * particular, it overrides the open_i() method to use the Acceptor
- * strategies tailored to use the SSL aware server connection handler.
- * See the TAO_IIOP_SSL_Connection_Handler notes for details.
- */
-class TAO_SSLIOP_Export TAO_IIOP_SSL_Acceptor
- : public TAO_IIOP_Acceptor
+namespace TAO
{
-public:
- typedef ACE_Strategy_Acceptor<TAO_IIOP_SSL_Connection_Handler, ACE_SOCK_ACCEPTOR> TAO_IIOP_SSL_BASE_ACCEPTOR;
- typedef TAO_Creation_Strategy<TAO_IIOP_SSL_Connection_Handler> TAO_IIOP_SSL_CREATION_STRATEGY;
- typedef TAO_Concurrency_Strategy<TAO_IIOP_SSL_Connection_Handler> TAO_IIOP_SSL_CONCURRENCY_STRATEGY;
- typedef TAO_Accept_Strategy<TAO_IIOP_SSL_Connection_Handler, ACE_SOCK_ACCEPTOR> TAO_IIOP_SSL_ACCEPT_STRATEGY;
+ /**
+ * @class IIOP_SSL_Acceptor
+ *
+ * @brief An SSL aware IIOP acceptor.
+ *
+ * The class differs from the non-SSL aware TAO_IIOP_Acceptor class
+ * since it uses a different a set of Acceptor strategies. In
+ * particular, it overrides the open_i() method to use the Acceptor
+ * strategies tailored to use the SSL aware server connection handler.
+ * See the TAO_IIOP_SSL_Connection_Handler notes for details.
+ */
+ class IIOP_SSL_Acceptor : public TAO_IIOP_Acceptor
+ {
+ public:
+
+ typedef ACE_Strategy_Acceptor<IIOP_SSL_Connection_Handler, ACE_SOCK_ACCEPTOR> TAO_IIOP_SSL_BASE_ACCEPTOR;
+ typedef TAO_Creation_Strategy<IIOP_SSL_Connection_Handler> TAO_IIOP_SSL_CREATION_STRATEGY;
+ typedef TAO_Concurrency_Strategy<IIOP_SSL_Connection_Handler> TAO_IIOP_SSL_CONCURRENCY_STRATEGY;
+ typedef TAO_Accept_Strategy<IIOP_SSL_Connection_Handler, ACE_SOCK_ACCEPTOR> TAO_IIOP_SSL_ACCEPT_STRATEGY;
- /// Constructor.
- TAO_IIOP_SSL_Acceptor (CORBA::Boolean flag = 0);
+ /// Constructor.
+ IIOP_SSL_Acceptor (CORBA::Boolean flag = 0);
- /// Destructor.
- ~TAO_IIOP_SSL_Acceptor (void);
+ /// Destructor.
+ ~IIOP_SSL_Acceptor (void);
- virtual int close (void);
+ virtual int close (void);
-protected:
+ protected:
- /// Implement the common part of the open*() methods. This method is
- /// virtual to allow a derived class implementation to be invoked
- /// instead.
- virtual int open_i (const ACE_INET_Addr &addr,
- ACE_Reactor *reactor);
+ /// Implement the common part of the open*() methods. This method
+ /// is virtual to allow a derived class implementation to be
+ /// invoked instead.
+ virtual int open_i (const ACE_INET_Addr &addr,
+ ACE_Reactor *reactor);
-private:
+ private:
- /// The concrete acceptor, as a pointer to it's base class.
- TAO_IIOP_SSL_BASE_ACCEPTOR base_acceptor_;
+ /// The concrete acceptor, as a pointer to it's base class.
+ TAO_IIOP_SSL_BASE_ACCEPTOR base_acceptor_;
- /**
- * @name Acceptor Strategies
- *
- * Server side creation, concurrency and accept strategies.
- */
- //@{
- TAO_IIOP_SSL_CREATION_STRATEGY *creation_strategy_;
- TAO_IIOP_SSL_CONCURRENCY_STRATEGY *concurrency_strategy_;
- TAO_IIOP_SSL_ACCEPT_STRATEGY *accept_strategy_;
- //@}
+ /**
+ * @name Acceptor Strategies
+ *
+ * Server side creation, concurrency and accept strategies.
+ */
+ //@{
+ TAO_IIOP_SSL_CREATION_STRATEGY *creation_strategy_;
+ TAO_IIOP_SSL_CONCURRENCY_STRATEGY *concurrency_strategy_;
+ TAO_IIOP_SSL_ACCEPT_STRATEGY *accept_strategy_;
+ //@}
+
+ /// State that will be passed to each SSLIOP connection handler upon
+ /// creation.
+ SSLIOP::Connection_Handler_State handler_state_;
- /// State that will be passed to each SSLIOP connection handler upon
- /// creation.
- TAO_SSLIOP_Connection_Handler_State handler_state_;
+ };
-};
+} // End TAO namespace.
#include /**/ "ace/post.h"